"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createHtmlOutput = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const diff2html_1 = require("diff2html");
const htmlTemplate = (diffHtml) => `<html>
<head>
  <title>GraphQL Schema Diff</title>
  <meta charset="utf-8" /> 
  <link rel="stylesheet" href="css/diff2html.min.css">
  <script src="js/diff2html.min.js"></script>
  <script src="js/diff2html-ui.min.js"></script>
  <style>
    html { box-sizing: border-box; }
    *,*:before,*:after { box-sizing: inherit; }
  </style>
</head>
<body>
  ${diffHtml}
</body>
</html>`;
async function createHtmlOutput(diff, options = {}) {
    const { outputDirectory = "schemaDiff" } = options;
    const adjustedDiff = diff
        .replace(/(---\s.*)\sremoved/, "$1")
        .replace(/(\+\+\+\s.*)\sadded/, "$1");
    const diffHtml = (0, diff2html_1.html)(adjustedDiff, {
        matching: "lines",
        outputFormat: "side-by-side",
        rawTemplates: {
            "tag-file-renamed": "",
        },
    });
    await fs_extra_1.default.ensureDir(outputDirectory);
    const diff2HtmlPath = path_1.default.dirname(require.resolve("diff2html/package.json"));
    await fs_extra_1.default.copy(path_1.default.join(diff2HtmlPath, "bundles"), outputDirectory);
    const htmlOutput = htmlTemplate(diffHtml);
    await fs_extra_1.default.writeFile(path_1.default.join(outputDirectory, "index.html"), htmlOutput);
}
exports.createHtmlOutput = createHtmlOutput;
